' (C) Copyright 2002-2007 by Autodesk, Inc. 
'
' Permission to use, copy, modify, and distribute this software in
' object code form for any purpose and without fee is hereby granted, 
' provided that the above copyright notice appears in all copies and 
' that both that copyright notice and the limited warranty and
' restricted rights notice below appear in all supporting 
' documentation.
'
' AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
' AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
' MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC. 
' DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
' UNINTERRUPTED OR ERROR FREE.
'
' Use, duplication, or disclosure by the U.S. Government is subject to 
' restrictions set forth in FAR 52.227-19 (Commercial Computer
' Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
' (Rights in Technical Data and Computer Software), as applicable.
'


Public Class MyVBClass

    <CommandMethod("HelloWorld")> _
    Public Sub MyMethod()

        ' Some variable definitions
        Dim activeDoc As Document
        Dim BTR As BlockTableRecord

        ' Store a reference to the currently active document (to make the next two lines of code  shorter)
        activeDoc = Application.DocumentManager.MdiActiveDocument

        ' Start a transaction to edit the DWG database
        Using trans As Transaction = activeDoc.Database.TransactionManager.StartTransaction()

            ' Open BlockTableRecord of currently active space ready to add entity. 
            ' (This will be ModelSpace if you've not switched to a layout, otherwise PaperSpace).
            BTR = trans.GetObject(activeDoc.Database.CurrentSpaceId, Autodesk.AutoCAD.DatabaseServices.OpenMode.ForWrite)

            ' Create a new MText entity 
            Dim txt As MText = New MText

            'Prompt for some text to customize the string we give the MText to display
            Dim txtOpts As New PromptStringOptions(vbLf & "Who should I say hello to?")
            txtOpts.DefaultValue = "World"
            txtOpts.AllowSpaces = True

            Dim txtRes As PromptResult = activeDoc.Editor.GetString(txtOpts)

            If txtRes.Status = PromptStatus.Cancel Then

                'If use pressed cancel, then they didn't want text inserted
                Exit Sub

            ElseIf txtRes.Status = PromptStatus.OK Then

                'If everything was ok, then we add the text entered by user into the MText string
                txt.Contents = "Hello " & txtRes.StringResult & " from VB.NET!"

            Else

                'If user did anything else, then we assume they wanted the default text
                txt.Contents = "Hello " & txtOpts.DefaultValue & " from VB.NET!"

            End If

            Dim ptOpts As New PromptPointOptions(vbLf & "Where do you want to place the text?")
            ptOpts.Keywords.Add("Origin")
            ptOpts.Keywords.Add("Random")

            Dim ptRes As PromptPointResult = activeDoc.Editor.GetPoint(ptOpts)

            Dim pt As Point3d
            If ptRes.Status = PromptStatus.Cancel Then

                'If user hit cancel we assume they wanted to cancel the whole command
                Exit Sub

            ElseIf ptRes.Status = PromptStatus.OK Then

                'If the user picked or typed in a point, then we just use that
                pt = ptRes.Value

            ElseIf ptRes.Status = PromptStatus.Keyword Then

                'If its a keyword we need to find out which one
                If ptRes.StringResult = "Origin" Then
                    pt = New Point3d(0, 0, 0)
                Else
                    'If its a keyword and not [Origin], then it must be [Random]
                    'I lied about the insertion point being random :-)
                    pt = New Point3d(1, 1, 0)
                End If

            Else

                'If anything else, we just insert the MText at (0,0,0)
                pt = New Point3d(0, 0, 0)

            End If

            'Create transformation matrix to translate text to selected insertion point
            '(Obviously this transformation does nothing if we selected (0,0,0))
            Dim mat As Matrix3d = Matrix3d.Displacement(pt.GetAsVector)

            'Move the text
            txt.TransformBy(mat)

            ' Add the MText to ModelSpace
            BTR.AppendEntity(txt)
            txt.SetDatabaseDefaults()

            ' Add the Mtext to the transaction
            trans.AddNewlyCreatedDBObject(txt, True)

            ' Commit transaction so changes persist in the DWG Database. 
            trans.Commit()

        End Using

    End Sub

End Class

